==> cosmology-2.19.0.tgz: package/README.md <==
# cosmology

<p align="center" width="100%">
  <a href="https://github.com/cosmology-tech/cosmology/actions/workflows/run-tests.yml">
    <img height="20" src="https://github.com/cosmology-tech/cosmology/actions/workflows/run-tests.yml/badge.svg" />
  </a>
   <a href="https://github.com/cosmology-tech/cosmology/blob/main/LICENSE"><img height="20" src="https://img.shields.io/badge/license-MIT-blue.svg"></a>
   <a href="https://www.npmjs.com/package/cosmology"><img height="20" src="https://img.shields.io/github/package-json/v/cosmology-tech/cosmology?filename=packages%2Fcosmology%2Fpackage.json"></a>
</p>

```
npm install -g cosmology
```

Use `cosmology` to build web3 applications on top of Osmosis and the Cosmos. Make cryptocurrency trades, join liquidity pools, and stake rewards.

While you can install `cosmology` directly, please read the docs for the CLI and TS/JS Library linked below.

## CLI

https://www.npmjs.com/package/@cosmology/cli

## TS/JS Library

https://www.npmjs.com/package/@cosmology/core

## Credits

🛠 Built by Cosmology — if you like our tools, please consider delegating to [our validator ⚛️](https://cosmology.tech/validator)

Code built with the help of these related projects:

* [@osmonauts/telescope](https://github.com/osmosis-labs/telescope) a "babel for the Cosmos", Telescope is a TypeScript Transpiler for Cosmos Protobufs.
* [osmojs](https://github.com/osmosis-labs/osmojs) OsmosJS makes it easy to compose and broadcast Osmosis and Cosmos messages.

## Disclaimer

AS DESCRIBED IN THE COSMOLOGY LICENSES, THE SOFTWARE IS PROVIDED “AS IS”, AT YOUR OWN RISK, AND WITHOUT WARRANTIES OF ANY KIND.

No developer or entity involved in creating Cosmology will be liable for any claims or damages whatsoever associated with your use, inability to use, or your interaction with other users of the Cosmology app or Cosmology CLI, including any direct, indirect, incidental, special, exemplary, punitive or consequential damages, or loss of profits, cryptocurrencies, tokens, or anything else of value.

==> cosmology-3.0.2.tgz: package/README.md <==
# cosmology

<p align="center" width="100%">
  <a href="https://github.com/cosmology-tech/cosmology/actions/workflows/run-tests.yml">
    <img height="20" src="https://github.com/cosmology-tech/cosmology/actions/workflows/run-tests.yml/badge.svg" />
  </a>
   <a href="https://github.com/cosmology-tech/cosmology/blob/main/LICENSE"><img height="20" src="https://img.shields.io/badge/license-MIT-blue.svg"></a>
   <a href="https://www.npmjs.com/package/cosmology"><img height="20" src="https://img.shields.io/github/package-json/v/cosmology-tech/cosmology?filename=packages%2Fcosmology%2Fpackage.json"></a>
</p>

```
npm install -g cosmology
```

Use `cosmology` to build web3 applications on top of Osmosis and the Cosmos. Make cryptocurrency trades, join liquidity pools, and stake rewards.

While you can install `cosmology` directly, please read the docs for the CLI and TS/JS Library linked below.

## CLI

https://www.npmjs.com/package/@cosmology/cli

## TS/JS Library

https://www.npmjs.com/package/@cosmology/core

## Credits

🛠 Built by Cosmology — if you like our tools, please consider delegating to [our validator ⚛️](https://cosmology.tech/validator)

Code built with the help of these related projects:

* [@cosmology/telescope](https://github.com/cosmology-tech/telescope) a "babel for the Cosmos", Telescope is a TypeScript Transpiler for Cosmos Protobufs.
* [osmojs](https://github.com/osmosis-labs/osmojs) OsmosJS makes it easy to compose and broadcast Osmosis and Cosmos messages.

## Disclaimer

AS DESCRIBED IN THE COSMOLOGY LICENSES, THE SOFTWARE IS PROVIDED “AS IS”, AT YOUR OWN RISK, AND WITHOUT WARRANTIES OF ANY KIND.

No developer or entity involved in creating Cosmology will be liable for any claims or damages whatsoever associated with your use, inability to use, or your interaction with other users of the Cosmology app or Cosmology CLI, including any direct, indirect, incidental, special, exemplary, punitive or consequential damages, or loss of profits, cryptocurrencies, tokens, or anything else of value.
